@@ -141,7 +141,7 @@ class BasicBWT(object):
             
         return (l, h)
     
-    def getSequenceDollarID(self, strIndex):
+    def getSequenceDollarID(self, strIndex, returnOffset=False):
         '''
         This will take a given index and work backwards until it encounters a '$' indicating which dollar ID is
         associated with this read
@@ -152,13 +152,19 @@ class BasicBWT(object):
         currIndex = strIndex
         prevChar = self.getCharAtIndex(currIndex)
         currIndex = self.getOccurrenceOfCharAtIndex(prevChar, currIndex)
+        i = 0
         
         #while we haven't looped back to the start
         while prevChar != 0:
             #figure out where to go from here
             prevChar = self.getCharAtIndex(currIndex)
             currIndex = self.getOccurrenceOfCharAtIndex(prevChar, currIndex)
-        return currIndex
+            i += 1
+        
+        if returnOffset:
+            return (currIndex, i)
+        else:
+            return currIndex
     
     def recoverString(self, strIndex, withIndex=False):
         '''
@@ -307,10 +313,10 @@ class MultiStringBWT(BasicBWT):
         '''
         return self.bwt[start:end]
         
-    def getOccurrenceOfCharAtIndex(self, char, index):
+    def getOccurrenceOfCharAtIndex(self, sym, index):
         '''
         This functions gets the FM-index value of a character at the specified position
-        @param char - the character to find the occurrence level
+        @param sym - the character to find the occurrence level
         @param index - the index we want to find the occurrence level at
         @return - the number of occurrences of char before the specified index
         '''
@@ -320,9 +326,9 @@ class MultiStringBWT(BasicBWT):
         
         #these two methods seem to have the same approximate run time
         if (binID << self.bitPower) == index:
-            ret = self.partialFM[binID][char]
+            ret = self.partialFM[binID][sym]
         else:
-            ret = self.partialFM[binID][char] + np.bincount(self.bwt[binID << self.bitPower:index], minlength=6)[char]
+            ret = self.partialFM[binID][sym] + np.bincount(self.bwt[binID << self.bitPower:index], minlength=6)[sym]
         return int(ret)
         
     def getFullFMAtIndex(self, index):
@@ -656,14 +662,14 @@ class CompressedMSBWT(BasicBWT):
         
         return ret
     
-    def getOccurrenceOfCharAtIndex(self, char, index):
+    def getOccurrenceOfCharAtIndex(self, sym, index):
         '''
         This functions gets the FM-index value of a character at the specified position
-        @param char - the character to find the occurrence level
+        @param sym - the character to find the occurrence level
         @param index - the index we want to find the occurrence level at
         @return - the number of occurrences of char before the specified index
         '''
-        return int(self.getFullFMAtIndex(index)[char])
+        return int(self.getFullFMAtIndex(index)[sym])
     
     def getFullFMAtIndex(self, index):
         '''
